from .shell import ShellResource, TikaResource, KaldiAspireResource, KaldiNLResource
from .http import (HttpResource, HttpFileResource, HttpImageResource, file_resource_delete_handler, URLResource,
                   MicroServiceResource, TestClientResource)
